# pylts

![Github CI](https://github.com/justmars/pylts/actions/workflows/main.yml/badge.svg)

Pydantic wrapper around litestreamed database specific to an AWS bucket.

## Development

See [documentation](https://justmars.github.io/pylts).

1. Run `poetry shell`
2. Run `poetry update`
3. Run `pytest`
